import { IForumRepository } from '@modules/foruns/repositories/IForumRepository';
import { AppError } from '@shared/error/AppError';
import 'reflect-metadata';
import { injectable, inject } from 'tsyringe';


interface IRequest {
    title: string,
    description: string
}

@injectable()
class CreateForumUseCase {
    constructor(
        @inject('ForumRepository')
        private forunsRepository: IForumRepository
    ) { }

    async execute({ title, description }: IRequest) {
        const forumAlreadyExists = await this.forunsRepository.findByTitle(title)
        if (forumAlreadyExists) {
            throw new AppError('Forum already exists', 404);
        }

        const forum = await this.forunsRepository.create({
            title,
            description
        })

        return forum
    }
}

export { CreateForumUseCase }